# arpes.utilities.bz\_spec module

Contains specifications and paths to BZs for some common materials.
These are useful if you know them ahead of hand, either from a picture,
from a DFT calculation, tight binding calculation, or explicit
specification.

This is used in the interactive BZ explorer in order to help with
orienting yourself in momentum.

Each zone definition corresponds to the following things:

1.    - The geometry, this gives the physical Brillouin zone size and  
        shape

2.  The material work function, if available

3.  The material inner potential, if available

4.  The material name

**arpes.utilities.bz\_spec.bz\_points\_for\_hexagonal\_lattice(a=1)**

**arpes.utilities.bz\_spec.image\_for(file)**
